@@ -1,5 +1,5 @@
 package Text::NeatTemplate;
-$Text::NeatTemplate::VERSION = '0.1200';
+$Text::NeatTemplate::VERSION = '0.1300';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ Text::NeatTemplate - a fast, middleweight template engine.
 
 =head1 VERSION
 
-version 0.1200
+version 0.1300
 
 =head1 SYNOPSIS
 
@@ -178,6 +178,12 @@ Convert to a string containing only alphanumeric characters
 and then prefix with a hash (#) character
 (useful for anchors or tags)
 
+=item alphahyphen
+
+Convert to a string containing alphanumeric characters, dashes
+and underscores; spaces are converted to hyphens.
+(useful for anchors or filenames)
+
 =item comma_front
 
 Put anything after the last comma at the front (as with an author name)
@@ -719,6 +725,15 @@ sub convert_value {
 	    $value =~ s/ /_/g;
 	    return $value;
 	};
+	/^alphahyphen/i && do {
+	    $value =~ s!/! !g;
+	    $value =~ s/[^a-zA-Z0-9_\s-]//g;
+            $value =~ s/^\s+//;
+            $value =~ s/\s+$//;
+	    $value =~ s/\s\s+/ /g;
+	    $value =~ s/ /-/g;
+	    return $value;
+	};
 	/^alphahash/i && do {
 	    $value =~ s/[^a-zA-Z0-9]//g;
             $value = "#${value}";
